/*
 * Copyright 2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*******************************************************************************
 * Includes
 ******************************************************************************/

#include "board.h"
#include "fsl_ctimer.h"
#include "fsl_gpio.h"

#include "pin_mux.h"
#include "clock_config.h"
#include "fsl_common.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define EXAMPLE_CTIMER CTIMER0                  /* Timer 0 */
#define EXAMPLE_CTIMER_MAT0_OUT kCTIMER_Match_0 /* Match output 1 */
#define EXAMPLE_CTIMER_MAT1_OUT kCTIMER_Match_1 /* Match output 0 */
#define EXAMPLE_CTIMER_CLK_FREQ CLOCK_GetFreq(kCLOCK_SysClk)

/*******************************************************************************
 * Prototypes
 ******************************************************************************/
void ctimer_match0_callback(uint32_t flags);
void ctimer_match1_callback(uint32_t flags);
extern ctimer_callback_t ctimer_callback_table[];

/*******************************************************************************
* Variables
******************************************************************************/
/* Match Configuration for Channel 0 */
static ctimer_match_config_t matchConfig0;
/* Match Configuration for Channel 1 */
static ctimer_match_config_t matchConfig1;

/*******************************************************************************
 * Code
 ******************************************************************************/

/* Array of function pointers for callback for each channel */
ctimer_callback_t ctimer_callback_table[] = {ctimer_match0_callback, ctimer_match1_callback, NULL, NULL};

void ctimer_match1_callback(uint32_t flags)
{
    static uint32_t count = 0;
    static uint32_t matchUpdateCount = 8;

    if (++count > matchUpdateCount)
    {
        count = 0;
        matchConfig1.matchValue >>= 1;
        matchUpdateCount <<= 1;
        if (matchUpdateCount == (1 << 8))
        {
            matchUpdateCount = 8;
            matchConfig1.matchValue = EXAMPLE_CTIMER_CLK_FREQ / 10;
        }
        CTIMER_SetupMatch(EXAMPLE_CTIMER, EXAMPLE_CTIMER_MAT1_OUT, &matchConfig1);
    }
}

void ctimer_match0_callback(uint32_t flags)
{
    static uint32_t count = 0;
    static uint32_t matchUpdateCount = 8;

    if (++count > matchUpdateCount)
    {
        count = 0;
        matchConfig0.matchValue >>= 1;
        matchUpdateCount <<= 1;
        if (matchUpdateCount == (1 << 8))
        {
            matchUpdateCount = 8;
            matchConfig0.matchValue = EXAMPLE_CTIMER_CLK_FREQ / 10;
        }
        CTIMER_SetupMatch(EXAMPLE_CTIMER, EXAMPLE_CTIMER_MAT0_OUT, &matchConfig0);
    }
}

/*!
 * @brief Main function
 */
int main(void)
{
    ctimer_config_t config;

    /* Init hardware*/
    BOARD_InitPins();
    BOARD_InitBootClocks();
    GPIO_PinWrite(GPIO, 6, 0);

    CTIMER_GetDefaultConfig(&config);

    CTIMER_Init(EXAMPLE_CTIMER, &config);

    /* Configuration 0 */
    matchConfig0.enableCounterReset = true;
    matchConfig0.enableCounterStop = false;
    matchConfig0.matchValue = EXAMPLE_CTIMER_CLK_FREQ / 10;
    matchConfig0.outControl = kCTIMER_Output_Toggle;
    matchConfig0.outPinInitState = false;
    matchConfig0.enableInterrupt = true;

    /* Configuration 1 */
    matchConfig1.enableCounterReset = true;
    matchConfig1.enableCounterStop = false;
    matchConfig1.matchValue = EXAMPLE_CTIMER_CLK_FREQ / 10;
    matchConfig1.outControl = kCTIMER_Output_Toggle;
    matchConfig1.outPinInitState = true;
    matchConfig1.enableInterrupt = true;

    CTIMER_RegisterCallBack(EXAMPLE_CTIMER, &ctimer_callback_table[0], kCTIMER_MultipleCallback);
    CTIMER_SetupMatch(EXAMPLE_CTIMER, EXAMPLE_CTIMER_MAT0_OUT, &matchConfig0);
    CTIMER_SetupMatch(EXAMPLE_CTIMER, EXAMPLE_CTIMER_MAT1_OUT, &matchConfig1);
    CTIMER_StartTimer(EXAMPLE_CTIMER);

    while (1)
    {
    }
}
