/*
 * Copyright 2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*******************************************************************************
 * Includes
 ******************************************************************************/

#include "board.h"
#include "fsl_ctimer.h"
#include "fsl_gpio.h"

#include "pin_mux.h"
#include "clock_config.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define EXAMPLE_CTIMER CTIMER0                 /* Timer 0 */
#define EXAMPLE_CTIMER_MAT_OUT kCTIMER_Match_0 /* Match output 0 */
#define EXAMPLE_CTIMER_CLK_FREQ CLOCK_GetFreq(kCLOCK_SysClk)

/*******************************************************************************
 * Prototypes
 ******************************************************************************/

/*******************************************************************************
* Variables
******************************************************************************/
volatile uint32_t g_pwmPeriod = 0U;
volatile uint32_t g_pulsePeriod = 0U;

/*******************************************************************************
 * Code
 ******************************************************************************/
status_t CTIMER_GetPwmPeriodValue(uint32_t pwmFreqHz, uint8_t dutyCyclePercent, uint32_t timerClock_Hz)
{
    /* Calculate PWM period match value */
    g_pwmPeriod = (timerClock_Hz / pwmFreqHz) - 1;

    /* Calculate pulse width match value */
    if (dutyCyclePercent == 0)
    {
        g_pulsePeriod = g_pwmPeriod + 1;
    }
    else
    {
        g_pulsePeriod = (g_pwmPeriod * (100 - dutyCyclePercent)) / 100;
    }
    return kStatus_Success;
}

/*!
 * @brief Main function
 */
int main(void)
{
    ctimer_config_t config;
    uint32_t srcClock_Hz;
    uint32_t timerClock;

    /* Init hardware*/
    BOARD_InitPins();
    BOARD_InitBootClocks();
    GPIO_PinWrite(GPIO, 6, 0);

    /* CTimer counter uses the AHB clock */
    srcClock_Hz = EXAMPLE_CTIMER_CLK_FREQ;

    CTIMER_GetDefaultConfig(&config);
    timerClock = srcClock_Hz / (config.prescale + 1);

    CTIMER_Init(EXAMPLE_CTIMER, &config);

    /* Get the PWM period match value and pulse width match value of 2Khz PWM signal with 20% dutycycle */
    CTIMER_GetPwmPeriodValue(2000, 20, timerClock);
    CTIMER_SetupPwmPeriod(EXAMPLE_CTIMER, EXAMPLE_CTIMER_MAT_OUT, g_pwmPeriod, g_pulsePeriod, false);
    CTIMER_StartTimer(EXAMPLE_CTIMER);

    while (1)
    {
    }
}
