/*
 * Copyright 2018 NXP.
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*******************************************************************************
 * Includes
 ******************************************************************************/
#include "fsl_device_registers.h"
#include "board.h"
#include "fsl_gpio.h"
#include "fsl_power.h"
#include "fsl_eeprom.h"
#include "pin_mux.h"
#include "clock_config.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define EEPROM_SOURCE_CLOCK kCLOCK_SysClk
#define EEPROM_CLK_FREQ CLOCK_GetFreq(kCLOCK_SysClk)
#define EXAMPLE_EEPROM EEPROM
#define EXAMPLE_EEPROM_TEST_BUFFER_SIZE (64)
#define EXAMPLE_EEPROM_TEST_OFFSET (0)
#define EXAMPLE_LED_ROW_PIN (2)
#define EXAMPLE_LED_COL_PIN (6)
/*******************************************************************************
* Prototypes
******************************************************************************/

/*******************************************************************************
 * Code
 ******************************************************************************/

void Delay(void)
{
    volatile uint32_t i = 0;
    for (i = 0; i < 8000; ++i)
    {
        __asm("NOP"); /* delay */
    }
}

/*!
* @brief Main function
*/
int main(void)
{
    int i = 0;
    bool dataMatchFlag = true;
    uint32_t sourceClock_Hz = 0;
    uint8_t read_buf[EXAMPLE_EEPROM_TEST_BUFFER_SIZE] = {0};
    uint8_t write_buf[EXAMPLE_EEPROM_TEST_BUFFER_SIZE] = {1, 5, 6, 8};
    /* fill eeprom config*/
    eeprom_config_t eeprom_config = {
        .autoProgram = kEEPROM_AutoProgramDisable,
        .writeWaitPhase1 = 0x5U,
        .writeWaitPhase2 = 0x9U,
        .writeWaitPhase3 = 0x3U,
        .readWaitPhase1 = 0xFU,
        .readWaitPhase2 = 0x8U,
        .lockTimingParam = false,
    };
    /* Init board hardware */
    BOARD_InitPins();
    BOARD_InitBootClocks();
    CLOCK_SetSysClkDiv(kCLOCK_SysClkFreq4MHZ); // 4M

    /* init eeprom */
    sourceClock_Hz = EEPROM_CLK_FREQ;
    EEPROM_Init(EEPROM, &eeprom_config, sourceClock_Hz);

    /* write data to eeprom */
    EEPROM_Write(EEPROM, EXAMPLE_EEPROM_TEST_OFFSET, write_buf, sizeof(write_buf));

    /* check data */
    for (i = 0; i < EXAMPLE_EEPROM_TEST_BUFFER_SIZE; i++)
    {
        read_buf[i] = (*(((uint8_t *)FSL_FEATURE_EEPROM_BASE_ADDRESS + i)));

        /* verify */
        if (write_buf[i] != read_buf[i])
        {
            /* test error */
            dataMatchFlag = false;
        }
    }
    if (dataMatchFlag)
    {
        BOARD_LedMatrixShowNumber(0, 0, false);
    }
    else
    {
        BOARD_LedMatrixShowNumber(1, 0, false);
    }
    while (1)
    {
    }
}
