/*
 * Copyright 2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*******************************************************************************
 * Includes
 ******************************************************************************/
#include "board.h"
#include "fsl_gpio.h"
#include "fsl_tsens.h"

#include "clock_config.h"
#include "pin_mux.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define DEMO_TSENS TSENS
#define DEMO_LED_BASE_PIN 6U
#define DEMO_LED_GPIO_BASE GPIO
#define DEMO_LED_CONTROL_PIN 2U

/*******************************************************************************
 * Prototypes
 ******************************************************************************/

/*******************************************************************************
 * Variables
 ******************************************************************************/
/* Monitor the high temperature threshold as 30 degrees Celsius. */
const uint32_t g_MonitorHighThreshold = 0x4BC9U;
/* Monitor the low temperature threshold as 28 degrees Celsius. */
const uint32_t g_MonitorLowThreshold = 0x4B49U;

/*******************************************************************************
 * Code
 ******************************************************************************/
static void BOARD_InitGpioPins()
{
    /* Define the init structure for the output LED pin*/
    gpio_pin_config_t led_config = {kGPIO_DigitalOutput, 0};

    /* Init output LED GPIO. */
    GPIO_PinInit(DEMO_LED_GPIO_BASE, DEMO_LED_BASE_PIN, &led_config);
    GPIO_PinInit(DEMO_LED_GPIO_BASE, DEMO_LED_CONTROL_PIN, &led_config);
}


/*!
 * @brief Main function.
 */
int main(void)
{
    tsens_config_t config;
    uint32_t temperature = 0U;
    bool highThresholdLedFlag = false;

    CLOCK_EnableClock(kCLOCK_Gpio);
    BOARD_InitPins();
    BOARD_InitBootClocks();
    BOARD_InitGpioPins();

    /*
     * config.outputMode = kTSENS_OutputCalibratedData;
     * config.resolutionMode = kTSENS_Resolution12bit;
     * config.enableVolatgeCalibration = false;
     */
    TSENS_GetDefaultConfig(&config);
    TSENS_Init(DEMO_TSENS, &config);

    while (1)
    {
        TSENS_StartMeasurement(DEMO_TSENS);
        while (kTSENS_ConversionSuccessFlag != (kTSENS_ConversionSuccessFlag & TSENS_GetStatusFlags(DEMO_TSENS)))
        {
        }
        temperature = TSENS_GetTemperature(DEMO_TSENS);

        if ((temperature > g_MonitorHighThreshold) && !highThresholdLedFlag)
        {
            /* Toggle the LED. */
            GPIO_PortToggle(GPIO, 1U << DEMO_LED_CONTROL_PIN);
            highThresholdLedFlag = true;
        }
        else if ((temperature < g_MonitorLowThreshold) && highThresholdLedFlag)
        {
            /* Toggle the LED. */
            GPIO_PortToggle(GPIO, 1U << DEMO_LED_CONTROL_PIN);
            highThresholdLedFlag = false;
        }
    }
}
